<?php

namespace FM\Controller;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use FM\Service\MinhasTarefasService;
use FM\Traits\TResponse;

class MinhasTarefasController
{

    use TResponse;

    protected $MinhasTarefasService;

    public function __construct($MinhasTarefasService)
    {
        $this->MinhasTarefasService = $MinhasTarefasService;
    }

    // -------> FUNÇÕES DA TELA LISTA DE TAREFAS <-------- //

    public function getTarefasListadas(Request $request)
    {
        try {
            $data = $this->MinhasTarefasService->getTarefasListadas($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getFotosTarefas(Request $request)
    {
        try {
            $data = $this->MinhasTarefasService->getFotosTarefas($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function excluirFotoTarefas(Request $request)
    {
        try {
            $data = $this->MinhasTarefasService->excluirFotoTarefas($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    // -----= FUNÇÕES DA TELA MINHAS TAREFAS

    public function anexarImagensTarefas(Request $request)
    {
        try {
            $data = $this->MinhasTarefasService->anexarImagensTarefas($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getMinhasTarefas(Request $request)
    {
        try {
            $data = $this->MinhasTarefasService->getMinhasTarefas($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getTarefasPorOperador()
    {
        try {
            $data = $this->MinhasTarefasService->getTarefasPorOperador();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }


    public function alterarStatusTarefa(Request $request)
    {
        try {
            $data = $this->MinhasTarefasService->alterarStatusTarefa($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    // Funções da Tela de Detalhamento
    public function getDetalhesTarefa(Request $request)
    {
        try {
            $data = $this->MinhasTarefasService->getDetalhesTarefa($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getItensTarefas(Request $request)
    {
        try {
            $data = $this->MinhasTarefasService->getItensTarefas($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function qtdTarefasAtivas()
    {
        try {
            $data = $this->MinhasTarefasService->qtdTarefasAtivas();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function finalizarTarefa(Request $request)
    {
        try {
            $data = $this->MinhasTarefasService->finalizarTarefa($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getDetailsTaskVistoria(DTO\Request $request, DTO\Response $response)
    {
        $response->addDataSet(new DataSet('details', $this->MinhasTarefasService->itensDetailsTaskForVistoria($request->getParameters())));
    }


    public function getitensDetailsTaskForVistoria(DTO\Request $request, DTO\Response $response)
    {
        $response->addDataSet(new DataSet('details', $this->MinhasTarefasService->itensDetailsTaskForVistoria($request->getParameters())));
    }
}
