import Vue from 'vue';
import Router from 'vue-router';
import { Config, Http } from '@zeedhi/core';
import { ZdPage } from '@zeedhi/vue';
import { TekLibLocalStorage } from '@zeedhi/tek-lib';
import { LoadingService } from '@zeedhi/common';
import { ZdFramePage } from '@zeedhi/vuetify';
import Store from './store';
import { Utilities } from './util/Utilities';

Vue.use(Router);

const router = new Router({
    mode: 'history',
    base: process.env.BASE_URL,
    routes: [
        {
            path: '/',
            name: 'home',
            component: () => import('./views/Home.vue'),
        },
        {
            path: '/zeedhi',
            name: 'zeedhi',
            component: ZdPage,
            props: () => ({
                path: 'zeedhi',
                local: true,
            }),
        },
        {
            path: '/Lista_Tarefas',
            name: 'ListaTarefas',
            component: ZdPage,
            props: () => ({
                path: 'listaTarefas',
                local: true,
            }),
        },
        {
            path: '/Tarefas',
            name: 'MinhasTarefas',
            component: ZdPage,
            props: () => ({
                path: 'fm_00001_000_tarefas/minhasTarefas',
                local: true,
            }),
        },
        {
            path: '/fm_00001_001_listagem_tarefas',
            name: 'Listagem de Tarefas',
            component: ZdFramePage,
            props: {
                type: 'post',
                params: {
                    jsonPath: 'fm_00001_000_tarefas/fm_00001_001_listagem_tarefas',
                    routePath: '/fm_00001_001_listagem_tarefas',
                },
            },
        },
        {
            path: '/fm_00001_000_tarefas',
            name: 'Minhas Tarefas',
            component: ZdFramePage,
            props: {
                type: 'post',
                params: {
                    jsonPath: 'fm_00001_000_tarefas/fm_00001_000_tarefas',
                    routePath: '/fm_00001_000_tarefas',
                },
            },
        },
        {
            path: '/auth/login',
            name: 'login',
            component: ZdPage,
            props: () => ({
                path: 'login',
                local: true,
            }),
        },
        {
            path: '/Detalhes_Tarefa/:nr',
            name: 'DetalhamentoTarefa',
            component: ZdPage,
            props: () => ({
                path: 'fm_00001_000_tarefas/detalhamentoTarefa',
                local: true,
            }),
        },
        {
            path: '/conformidades',
            name: 'Não_Conformidades',
            component: ZdPage,
            props: () => ({
                path: 'conformidades',
                local: true,
            }),
        },
        {
            path: '/fm_00011_000_analise_nao_conformidade',
            name: 'Análise de Não Conformidades',
            component: ZdFramePage,
            props: {
                type: 'post',
                params: {
                    jsonPath: 'fm_00011_000_analise_nao_conformidade/fm_00011_000_analise_nao_conformidade',
                    routePath: '/fm_00011_000_analise_nao_conformidade',
                },
            },
        },
        {
            path: '/Reportar_Tarefa/:nr',
            name: 'ReportarTarefa',
            component: ZdPage,
            props: () => ({
                path: 'reportarTarefa',
                local: true,
            }),
        },
        {
            path: '/fm_00001_000_detalhamento_tarefa',
            name: 'Detalhes Tarefa',
            component: ZdFramePage,
            props: {
                type: 'post',
                params: {
                    jsonPath: 'fm_00001_000_tarefas/fm_00001_000_detalhamento_tarefa',
                    routePath: '/fm_00001_000_detalhamento_tarefa',
                },
            },
        },
        {
            path: '/fm_00001_000_reportar_tarefa',
            name: 'Reportar Tarefa',
            component: ZdFramePage,
            props: {
                type: 'post',
                params: {
                    jsonPath: 'fm_00001_000_tarefas/fm_00001_000_reportar_tarefa',
                    routePath: '/fm_00001_000_reportar_tarefa',
                },
            },
        },
        {
            path: '/fm_00000_000_dashboard',
            name: 'Dashboard',
            component: ZdFramePage,
            props: {
                type: 'post',
                params: {
                    jsonPath: 'fm_00000_000_dashboard/fm_00000_000_dashboard',
                    routePath: '/fm_00000_000_dashboard',
                },
            },
        },
        {
            path: '/Vistorias',
            name: 'Vistorias',
            component: ZdPage,
            props: () => ({
                path: 'listagemVistorias',
                local: true,
            }),
        },
        {
            path: '/fm_00002_000_vistoria',
            name: 'Listagem de Vistorias',
            component: ZdFramePage,
            props: {
                type: 'post',
                params: {
                    jsonPath: 'fm_00002_000_vistoria/fm_00002_000_vistoria',
                    routePath: '/fm_00002_000_vistoria',
                },
            },
        },
        {
            path: '/Detalhes_Vistoria/:nr/:local',
            name: 'Vistoria',
            component: ZdPage,
            props: () => ({
                path: 'fm_00002_000_vistoria/detalhesVistoria',
                local: true,
            }),
        },
        {
            path: '/Calendario',
            name: 'Calendario',
            component: ZdPage,
            props: () => ({
                path: 'calendario',
                local: true,
            }),
        },
        {
            path: '/registrarApontamento',
            name: 'Registrar_Apontamento',
            component: ZdPage,
            props: () => ({
                path: 'registrarApontamento',
                local: true,
            }),
        },
        {
            path: '/fm_00021_000_registrar_apontamento',
            name: 'Registrar Apontamento',
            component: ZdFramePage,
            props: {
                type: 'post',
                params: {
                    jsonPath: 'fm_00021_000_apontamento/fm_00021_000_registrar_apontamento',
                    routePath: '/fm_00021_000_registrar_apontamento',
                },
            },
        },
        {
            path: '/fm_00020_000_solicitacoes',
            name: 'Solicitações',
            component: ZdFramePage,
            props: {
                type: 'post',
                params: {
                    jsonPath: 'fm_00020_000_solicitacoes/fm_00020_000_solicitacoes',
                    routePath: '/fm_00020_000_solicitacoes',
                },
            },
        },
        {
            path: '/fm_00021_001_registrar_falta',
            name: 'Registrar Falta',
            component: ZdFramePage,
            props: {
                type: 'post',
                params: {
                    jsonPath: 'fm_00021_000_apontamento/fm_00021_001_registrar_falta',
                    routePath: '/fm_00021_001_registrar_falta',
                },
            },
        },
        {
            path: '/solicitacaoTarefa',
            name: 'Solicitacao_Tarefaa',
            component: ZdPage,
            props: () => ({
                path: 'solicitacaoTarefa',
                local: true,
            }),
        },
        {
            path: '/criarSolicitacao',
            name: 'criar_solicitacao',
            component: ZdPage,
            props: () => ({
                path: 'criarSolicitacaoTarefa',
                local: true,
            }),
        },
        {
            path: '/avaliarSolicitacao',
            name: 'avaliar_solicitacao',
            component: ZdPage,
            props: () => ({
                path: 'avaliarSolicitacao',
                local: true,
            }),
        },
        {
            path: '/modules/:module/:page',
            name: 'microservice',
            component: () => import('./views/Microservice.vue'),
        },
        {
            path: '*',
            component: ZdPage,
            props: {
                path: 'notfound',
                local: true,
            },
        },
    ],
});

const isOpeningNewModule = function isOpeningNewModule(to: any, from: any) {
    const isFromProduct = (to.name === 'microservice' && from.name !== 'microservice');
    // eslint-disable-next-line max-len
    const isFromAnotherModule = ((to.name === 'microservice' && from.name === 'microservice') && to.path.split('/')[2] !== from.path.split('/')[2]);
    const isNotLoginRoute = (to.fullPath !== Config.env.modules.login.routePath);
    return ((isFromProduct || isFromAnotherModule) && isNotLoginRoute);
};

// eslint-disable-next-line max-len
const callLibStartSessionFromModule = async function callLibStartSessionFromModule(to: any) {
    const data = {
        USER: localStorage.getItem('LOGIN_USER'),
        LOGIN_LANGUAGE: localStorage.getItem('LOGIN_LAGUAGE'),
        LOGIN_TOKEN: localStorage.getItem('LOGIN_TOKEN'),
    };
    await Http.post(`${Config.env.modules[to.path.split('/')[2]].endPoint}/lib_startSession`, data);
};

router.beforeEach(async (to, from, next) => {
    if (/Android|webOS|iPhone|iPad|iPod|BlackBerry|IEMobile|Opera Mini/i.test(navigator.userAgent) && to.name === 'microservice') {
        Utilities.mensagens('Error!', 'A tela desejada ainda nÃ£o foi preparada para o ambiente mobile. <br> <br> Favor acessar essa tela por um notebook ou desktop.');
        return;
    }

    if (isOpeningNewModule(to, from)) {
        try {
            LoadingService.show();
            await callLibStartSessionFromModule(to);
            LoadingService.hide();
        } catch (e) {
            LoadingService.hide();
        }
    }

    /** open old application - init */
    if (window.parent !== window && to.name !== 'token-error' && to.name !== 'microservice') { // if application is called inside a iframe
        if (to.query.token) {
            // if token was passed
            localStorage.setItem('LOGIN_TOKEN', to.query.token.toString());
            localStorage.setItem('LOGIN_USER', to.query.user.toString());
            localStorage.setItem('LOGIN_LANGUAGE', to.query.languange.toString());
            localStorage.setItem('PRODUCT_ID', to.query.productId.toString());
            if (to.query.hash !== '0') {
                localStorage.setItem('LOGIN_HASH', to.query.hash.toString());
            }
            Store.commit('setAppLoginToken', to.query.token);
            Store.commit('setAppDisplayOptions', { menu: to.query.menu, header: to.query.header });
        }

        if (!Store.state.appLoginToken) {
            // if there is no token... redirect to another page
            Store.commit('setAppDisplayOptions', { menu: '0', header: '0' });
            next('/token-error');
            return;
        }

        // remove parameters from requested page
        delete to.query.menu;
        delete to.query.header;
        delete to.query.token;

        TekLibLocalStorage.setItem('IS_NEXT', false);
        TekLibLocalStorage.setItem('LOGIN_KEEP_CONNECTED', 'Yes');
        TekLibLocalStorage.removeItem('routeParams');

        next();
    } else {
        TekLibLocalStorage.setItem('IS_NEXT', true);
    }
    /** open old application - end */

    if (to.path !== Config.env.loginRoutePath && !localStorage.getItem('LOGIN_TOKEN')) {
        next(Config.env.loginRoutePath);
    } else if (to.path === Config.env.loginRoutePath && localStorage.getItem('LOGIN_TOKEN')) {
        next(Config.env.baseUrl);
    } else {
        next();
    }
});

router.afterEach((to, from) => {
    const htmlElement = document.getElementsByTagName('html')[0];
    if (to.name === 'microservice') {
        htmlElement.setAttribute('microservice', '');
        Store.commit('setRouterParams', to.params);
        const frame = (document.getElementById('microservice-frame') as HTMLIFrameElement);
        if (frame && frame.contentWindow && to.path.split('/')[2] === from.path.split('/')[2]) {
            frame.contentWindow.postMessage({
                type: 'microservice-route-change',
                routerParams: to.params,
            }, `${Config.env.modules[to.path.split('/')[2]].baseUrl}`);
        }
        window.document.title = `${Config.env.product.name} - ${to.params.page}`;
    } else {
        htmlElement.removeAttribute('microservice');
        window.document.title = Config.env.product.name;
    }

    if (to.name === 'login') {
        htmlElement.setAttribute('login', '');
    } else {
        htmlElement.removeAttribute('login');
    }
});

export const getRouteParams = () => {
    const { currentRoute } = router;
    const { params } = currentRoute;
    return params;
};

export const getRoutePath = () => {
    const { currentRoute } = router;
    const { path } = currentRoute;
    return path;
};

export default router;
